" Vim indent file
" Language:	Expect
" Maintainer:	Doug Kearns <dougkearns@gmail.com>
" Last Change:	2022 Jul 16

if exists("b:did_indent")
  finish
endif

" Syntax is similar to Tcl
runtime! indent/tcl.vim
