vim9script

# Vim syntax file
# Language: ConTeXt
# Automatically generated by mtx-interface (2022-08-12 10:49)

syn keyword texAleph Alephminorversion Alephrevision Alephversion contained
syn keyword texEtex botmarks clubpenalties currentgrouplevel currentgrouptype currentifbranch contained
syn keyword texEtex currentiflevel currentiftype detokenize dimexpr displaywidowpenalties contained
syn keyword texEtex everyeof firstmarks fontchardp fontcharht fontcharic contained
syn keyword texEtex fontcharwd glueexpr glueshrink glueshrinkorder gluestretch contained
syn keyword texEtex gluestretchorder gluetomu ifcsname ifdefined iffontchar contained
syn keyword texEtex interactionmode interlinepenalties lastlinefit lastnodetype marks contained
syn keyword texEtex muexpr mutoglue numexpr pagediscards parshapedimen contained
syn keyword texEtex parshapeindent parshapelength predisplaydirection protected savinghyphcodes contained
syn keyword texEtex savingvdiscards scantokens showgroups showifs showtokens contained
syn keyword texEtex splitbotmarks splitdiscards splitfirstmarks topmarks tracingassigns contained
syn keyword texEtex tracinggroups tracingifs tracingnesting unexpanded unless contained
syn keyword texEtex widowpenalties contained
syn keyword texLuatex Uabove Uabovewithdelims Uatop Uatopwithdelims Uchar contained
syn keyword texLuatex Udelcode Udelcodenum Udelimiter Udelimiterover Udelimiterunder contained
syn keyword texLuatex Uhextensible Uleft Umathaccent Umathaccentbasedepth Umathaccentbaseheight contained
syn keyword texLuatex Umathaccentbottomovershoot Umathaccentbottomshiftdown Umathaccentsuperscriptdrop Umathaccentsuperscriptpercent Umathaccenttopovershoot contained
syn keyword texLuatex Umathaccenttopshiftup Umathaccentvariant Umathadapttoleft Umathadapttoright Umathaxis contained
syn keyword texLuatex Umathbotaccentvariant Umathchar Umathcharclass Umathchardef Umathcharfam contained
syn keyword texLuatex Umathcharnum Umathcharnumdef Umathcharslot Umathclass Umathcode contained
syn keyword texLuatex Umathcodenum Umathconnectoroverlapmin Umathdegreevariant Umathdelimiterovervariant Umathdelimiterpercent contained
syn keyword texLuatex Umathdelimitershortfall Umathdelimiterundervariant Umathdenominatorvariant Umathdict Umathdictdef contained
syn keyword texLuatex Umathextrasubpreshift Umathextrasubprespace Umathextrasubshift Umathextrasubspace Umathextrasuppreshift contained
syn keyword texLuatex Umathextrasupprespace Umathextrasupshift Umathextrasupspace Umathflattenedaccentbasedepth Umathflattenedaccentbaseheight contained
syn keyword texLuatex Umathflattenedaccentbottomshiftdown Umathflattenedaccenttopshiftup Umathfractiondelsize Umathfractiondenomdown Umathfractiondenomvgap contained
syn keyword texLuatex Umathfractionnumup Umathfractionnumvgap Umathfractionrule Umathfractionvariant Umathhextensiblevariant contained
syn keyword texLuatex Umathlimitabovebgap Umathlimitabovekern Umathlimitabovevgap Umathlimitbelowbgap Umathlimitbelowkern contained
syn keyword texLuatex Umathlimitbelowvgap Umathlimits Umathnoaxis Umathnolimits Umathnolimitsubfactor contained
syn keyword texLuatex Umathnolimitsupfactor Umathnumeratorvariant Umathopenupdepth Umathopenupheight Umathoperatorsize contained
syn keyword texLuatex Umathoverbarkern Umathoverbarrule Umathoverbarvgap Umathoverdelimiterbgap Umathoverdelimitervariant contained
syn keyword texLuatex Umathoverdelimitervgap Umathoverlayaccentvariant Umathoverlinevariant Umathphantom Umathpresubshiftdistance contained
syn keyword texLuatex Umathpresupshiftdistance Umathprimeraise Umathprimeraisecomposed Umathprimeshiftdrop Umathprimeshiftup contained
syn keyword texLuatex Umathprimespaceafter Umathprimevariant Umathprimewidth Umathquad Umathradicaldegreeafter contained
syn keyword texLuatex Umathradicaldegreebefore Umathradicaldegreeraise Umathradicalkern Umathradicalrule Umathradicalvariant contained
syn keyword texLuatex Umathradicalvgap Umathruledepth Umathruleheight Umathskeweddelimitertolerance Umathskewedfractionhgap contained
syn keyword texLuatex Umathskewedfractionvgap Umathsource Umathspaceafterscript Umathspacebeforescript Umathstackdenomdown contained
syn keyword texLuatex Umathstacknumup Umathstackvariant Umathstackvgap Umathsubscriptvariant Umathsubshiftdistance contained
syn keyword texLuatex Umathsubshiftdown Umathsubshiftdrop Umathsubsupshiftdown Umathsubsupvgap Umathsubtopmax contained
syn keyword texLuatex Umathsupbottommin Umathsuperscriptvariant Umathsupshiftdistance Umathsupshiftdrop Umathsupshiftup contained
syn keyword texLuatex Umathsupsubbottommax Umathtopaccentvariant Umathunderbarkern Umathunderbarrule Umathunderbarvgap contained
syn keyword texLuatex Umathunderdelimiterbgap Umathunderdelimitervariant Umathunderdelimitervgap Umathunderlinevariant Umathuseaxis contained
syn keyword texLuatex Umathvextensiblevariant Umathvoid Umathxscale Umathyscale Umiddle contained
syn keyword texLuatex Unosubprescript Unosubscript Unosuperprescript Unosuperscript Uoperator contained
syn keyword texLuatex Uover Uoverdelimiter Uoverwithdelims Uprimescript Uradical contained
syn keyword texLuatex Uright Uroot Ushiftedsubprescript Ushiftedsubscript Ushiftedsuperprescript contained
syn keyword texLuatex Ushiftedsuperscript Uskewed Uskewedwithdelims Ustack Ustartdisplaymath contained
syn keyword texLuatex Ustartmath Ustartmathmode Ustopdisplaymath Ustopmath Ustopmathmode contained
syn keyword texLuatex Ustyle Usubprescript Usubscript Usuperprescript Usuperscript contained
syn keyword texLuatex Uunderdelimiter Uvextensible adjustspacing adjustspacingshrink adjustspacingstep contained
syn keyword texLuatex adjustspacingstretch afterassigned aftergrouped aliased alignmark contained
syn keyword texLuatex alignmentcellsource alignmentwrapsource aligntab allcrampedstyles alldisplaystyles contained
syn keyword texLuatex allmathstyles allscriptscriptstyles allscriptstyles allsplitstyles alltextstyles contained
syn keyword texLuatex alluncrampedstyles atendofgroup atendofgrouped attribute attributedef contained
syn keyword texLuatex automaticdiscretionary automatichyphenpenalty automigrationmode autoparagraphmode begincsname contained
syn keyword texLuatex beginlocalcontrol beginmathgroup beginsimplegroup boundary boxadapt contained
syn keyword texLuatex boxanchor boxanchors boxattribute boxdirection boxfreeze contained
syn keyword texLuatex boxgeometry boxorientation boxrepack boxshift boxsource contained
syn keyword texLuatex boxtarget boxtotal boxxmove boxxoffset boxymove contained
syn keyword texLuatex boxyoffset catcodetable clearmarks copymathatomrule copymathparent contained
syn keyword texLuatex copymathspacing crampeddisplaystyle crampedscriptscriptstyle crampedscriptstyle crampedtextstyle contained
syn keyword texLuatex csstring currentloopiterator currentloopnesting currentmarks defcsname contained
syn keyword texLuatex detokenized dimensiondef dimexpression directlua edefcsname contained
syn keyword texLuatex efcode endlocalcontrol endmathgroup endsimplegroup enforced contained
syn keyword texLuatex etoks etoksapp etokspre everybeforepar everymathatom contained
syn keyword texLuatex everytab exceptionpenalty expand expandafterpars expandafterspaces contained
syn keyword texLuatex expandcstoken expanded expandedafter expandedloop expandtoken contained
syn keyword texLuatex explicitdiscretionary explicithyphenpenalty firstvalidlanguage flushmarks fontcharta contained
syn keyword texLuatex fontid fontmathcontrol fontspecdef fontspecid fontspecifiedsize contained
syn keyword texLuatex fontspecscale fontspecxscale fontspecyscale fonttextcontrol formatname contained
syn keyword texLuatex frozen futurecsname futuredef futureexpand futureexpandis contained
syn keyword texLuatex futureexpandisap gdefcsname gleaders glet gletcsname contained
syn keyword texLuatex glettonothing gluespecdef glyphdatafield glyphoptions glyphscale contained
syn keyword texLuatex glyphscriptfield glyphscriptscale glyphscriptscriptscale glyphstatefield glyphtextscale contained
syn keyword texLuatex glyphxoffset glyphxscale glyphxscaled glyphyoffset glyphyscale contained
syn keyword texLuatex glyphyscaled gtoksapp gtokspre hccode hjcode contained
syn keyword texLuatex hpack hyphenationmin hyphenationmode ifabsdim ifabsnum contained
syn keyword texLuatex ifarguments ifboolean ifchkdim ifchknum ifcmpdim contained
syn keyword texLuatex ifcmpnum ifcondition ifcstok ifdimexpression ifdimval contained
syn keyword texLuatex ifempty ifflags ifhaschar ifhastok ifhastoks contained
syn keyword texLuatex ifhasxtoks ifincsname ifinsert ifmathparameter ifmathstyle contained
syn keyword texLuatex ifnumexpression ifnumval ifparameter ifparameters ifrelax contained
syn keyword texLuatex iftok ignorearguments ignorepars immediate immutable contained
syn keyword texLuatex indexofcharacter indexofregister inherited initcatcodetable insertbox contained
syn keyword texLuatex insertcopy insertdepth insertdistance insertheight insertheights contained
syn keyword texLuatex insertlimit insertmaxdepth insertmode insertmultiplier insertpenalty contained
syn keyword texLuatex insertprogress insertstorage insertstoring insertunbox insertuncopy contained
syn keyword texLuatex insertwidth instance integerdef lastarguments lastatomclass contained
syn keyword texLuatex lastboundary lastchkdim lastchknum lastleftclass lastloopiterator contained
syn keyword texLuatex lastnamedcs lastnodesubtype lastpageextra lastparcontext lastrightclass contained
syn keyword texLuatex leftmarginkern letcharcode letcsname letfrozen letmathatomrule contained
syn keyword texLuatex letmathparent letmathspacing letprotected lettonothing linebreakcriterium contained
syn keyword texLuatex linedirection localbrokenpenalty localcontrol localcontrolled localcontrolledloop contained
syn keyword texLuatex localinterlinepenalty localleftbox localleftboxbox localmiddlebox localmiddleboxbox contained
syn keyword texLuatex localrightbox localrightboxbox lpcode luabytecode luabytecodecall contained
syn keyword texLuatex luacopyinputnodes luadef luaescapestring luafunction luafunctioncall contained
syn keyword texLuatex luatexbanner luatexrevision luatexversion mathaccent mathatom contained
syn keyword texLuatex mathatomglue mathatomskip mathbackwardpenalties mathbeginclass mathcheckfencesmode contained
syn keyword texLuatex mathdictgroup mathdictproperties mathdirection mathdisplaymode mathdisplayskipmode contained
syn keyword texLuatex mathdoublescriptmode mathendclass matheqnogapstep mathfenced mathfontcontrol contained
syn keyword texLuatex mathforwardpenalties mathfrac mathghost mathgluemode mathgroupingmode contained
syn keyword texLuatex mathinlinemainstyle mathleftclass mathlimitsmode mathmiddle mathnolimitsmode contained
syn keyword texLuatex mathpenaltiesmode mathrad mathrightclass mathrulesfam mathrulesmode contained
syn keyword texLuatex mathscale mathscriptsmode mathslackmode mathspacingmode mathstackstyle contained
syn keyword texLuatex mathstyle mathstylefontid mathsurroundmode mathsurroundskip maththreshold contained
syn keyword texLuatex mugluespecdef mutable noaligned noatomruling noboundary contained
syn keyword texLuatex nohrule norelax normalizelinemode normalizeparmode nospaces contained
syn keyword texLuatex novrule numericscale numexpression orelse orphanpenalties contained
syn keyword texLuatex orphanpenalty orunless outputbox overloaded overloadmode contained
syn keyword texLuatex pageboundary pageextragoal pagevsize parametercount parametermark contained
syn keyword texLuatex parattribute pardirection permanent pettymuskip postexhyphenchar contained
syn keyword texLuatex posthyphenchar postinlinepenalty prebinoppenalty predisplaygapfactor preexhyphenchar contained
syn keyword texLuatex prehyphenchar preinlinepenalty prerelpenalty protrudechars protrusionboundary contained
syn keyword texLuatex pxdimen quitloop quitvmode resetmathspacing retokenized contained
syn keyword texLuatex rightmarginkern rpcode savecatcodetable scaledemwidth scaledexheight contained
syn keyword texLuatex scaledextraspace scaledinterwordshrink scaledinterwordspace scaledinterwordstretch scaledmathstyle contained
syn keyword texLuatex scaledslantperpoint scantextokens semiexpand semiexpanded semiprotected contained
syn keyword texLuatex setdefaultmathcodes setfontid setmathatomrule setmathdisplaypostpenalty setmathdisplayprepenalty contained
syn keyword texLuatex setmathignore setmathoptions setmathpostpenalty setmathprepenalty setmathspacing contained
syn keyword texLuatex shapingpenaltiesmode shapingpenalty skewed skewedwithdelims snapshotpar contained
syn keyword texLuatex supmarkmode swapcsvalues tabsize textdirection thewithoutunit contained
syn keyword texLuatex tinymuskip todimension tohexadecimal tointeger tokenized contained
syn keyword texLuatex toksapp tokspre tolerant tomathstyle toscaled contained
syn keyword texLuatex tosparsedimension tosparsescaled tpack tracingadjusts tracingalignments contained
syn keyword texLuatex tracingexpressions tracingfonts tracingfullboxes tracinghyphenation tracinginserts contained
syn keyword texLuatex tracinglevels tracingmarks tracingmath tracingnodes tracingpenalties contained
syn keyword texLuatex uleaders undent unexpandedloop unletfrozen unletprotected contained
syn keyword texLuatex untraced vpack wordboundary wrapuppar xdefcsname contained
syn keyword texLuatex xtoks xtoksapp xtokspre contained
syn keyword texOmega Omegaminorversion Omegarevision Omegaversion contained
syn keyword texPdftex ifpdfabsdim ifpdfabsnum ifpdfprimitive pdfadjustspacing pdfannot contained
syn keyword texPdftex pdfcatalog pdfcolorstack pdfcolorstackinit pdfcompresslevel pdfcopyfont contained
syn keyword texPdftex pdfcreationdate pdfdecimaldigits pdfdest pdfdestmargin pdfdraftmode contained
syn keyword texPdftex pdfeachlinedepth pdfeachlineheight pdfendlink pdfendthread pdffirstlineheight contained
syn keyword texPdftex pdffontattr pdffontexpand pdffontname pdffontobjnum pdffontsize contained
syn keyword texPdftex pdfgamma pdfgentounicode pdfglyphtounicode pdfhorigin pdfignoreddimen contained
syn keyword texPdftex pdfignoreunknownimages pdfimageaddfilename pdfimageapplygamma pdfimagegamma pdfimagehicolor contained
syn keyword texPdftex pdfimageresolution pdfincludechars pdfinclusioncopyfonts pdfinclusionerrorlevel pdfinfo contained
syn keyword texPdftex pdfinfoomitdate pdfinsertht pdflastannot pdflastlinedepth pdflastlink contained
syn keyword texPdftex pdflastobj pdflastxform pdflastximage pdflastximagepages pdflastxpos contained
syn keyword texPdftex pdflastypos pdflinkmargin pdfliteral pdfmajorversion pdfmapfile contained
syn keyword texPdftex pdfmapline pdfminorversion pdfnames pdfnoligatures pdfnormaldeviate contained
syn keyword texPdftex pdfobj pdfobjcompresslevel pdfomitcharset pdfomitcidset pdfoutline contained
syn keyword texPdftex pdfoutput pdfpageattr pdfpagebox pdfpageheight pdfpageref contained
syn keyword texPdftex pdfpageresources pdfpagesattr pdfpagewidth pdfpkfixeddpi pdfpkmode contained
syn keyword texPdftex pdfpkresolution pdfprimitive pdfprotrudechars pdfpxdimen pdfrandomseed contained
syn keyword texPdftex pdfrecompress pdfrefobj pdfrefxform pdfrefximage pdfreplacefont contained
syn keyword texPdftex pdfrestore pdfretval pdfsave pdfsavepos pdfsetmatrix contained
syn keyword texPdftex pdfsetrandomseed pdfstartlink pdfstartthread pdfsuppressoptionalinfo pdfsuppressptexinfo contained
syn keyword texPdftex pdftexbanner pdftexrevision pdftexversion pdfthread pdfthreadmargin contained
syn keyword texPdftex pdftracingfonts pdftrailer pdftrailerid pdfuniformdeviate pdfuniqueresname contained
syn keyword texPdftex pdfvorigin pdfxform pdfxformattr pdfxformmargin pdfxformname contained
syn keyword texPdftex pdfxformresources pdfximage contained
syn keyword texTex   - / above abovedisplayshortskip contained
syn keyword texTex abovedisplayskip abovewithdelims accent adjdemerits advance contained
syn keyword texTex afterassignment aftergroup aligncontent atop atopwithdelims contained
syn keyword texTex badness baselineskip batchmode begingroup belowdisplayshortskip contained
syn keyword texTex belowdisplayskip binoppenalty botmark box boxmaxdepth contained
syn keyword texTex brokenpenalty catcode char chardef cleaders contained
syn keyword texTex clubpenalty copy count countdef cr contained
syn keyword texTex crcr csname day deadcycles def contained
syn keyword texTex defaulthyphenchar defaultskewchar delcode delimiter delimiterfactor contained
syn keyword texTex delimitershortfall dimen dimendef discretionary displayindent contained
syn keyword texTex displaylimits displaystyle displaywidowpenalty displaywidth divide contained
syn keyword texTex doublehyphendemerits dp dump edef else contained
syn keyword texTex emergencystretch end endcsname endgroup endinput contained
syn keyword texTex endlinechar eqno errhelp errmessage errorcontextlines contained
syn keyword texTex errorstopmode escapechar everycr everydisplay everyhbox contained
syn keyword texTex everyjob everymath everypar everyvbox exhyphenchar contained
syn keyword texTex exhyphenpenalty expandafter fam fi finalhyphendemerits contained
syn keyword texTex firstmark floatingpenalty font fontdimen fontname contained
syn keyword texTex fontspecifiedname futurelet gdef global globaldefs contained
syn keyword texTex glyph halign hangafter hangindent hbadness contained
syn keyword texTex hbox hfil hfill hfilneg hfuzz contained
syn keyword texTex holdinginserts holdingmigrations hrule hsize hskip contained
syn keyword texTex hss ht hyphenation hyphenchar hyphenpenalty contained
syn keyword texTex if ifcase ifcat ifdim iffalse contained
syn keyword texTex ifhbox ifhmode ifinner ifmmode ifnum contained
syn keyword texTex ifodd iftrue ifvbox ifvmode ifvoid contained
syn keyword texTex ifx ignorespaces indent input inputlineno contained
syn keyword texTex insert insertpenalties interlinepenalty jobname kern contained
syn keyword texTex language lastbox lastkern lastpenalty lastskip contained
syn keyword texTex lccode leaders left lefthyphenmin leftskip contained
syn keyword texTex leqno let limits linepenalty lineskip contained
syn keyword texTex lineskiplimit long looseness lower lowercase contained
syn keyword texTex mark mathbin mathchar mathchardef mathchoice contained
syn keyword texTex mathclose mathcode mathinner mathop mathopen contained
syn keyword texTex mathord mathpunct mathrel mathsurround maxdeadcycles contained
syn keyword texTex maxdepth meaning meaningasis meaningfull meaningless contained
syn keyword texTex medmuskip message middle mkern month contained
syn keyword texTex moveleft moveright mskip multiply muskip contained
syn keyword texTex muskipdef newlinechar noalign noexpand noindent contained
syn keyword texTex nolimits nonscript nonstopmode nulldelimiterspace nullfont contained
syn keyword texTex number omit or outer output contained
syn keyword texTex outputpenalty over overfullrule overline overshoot contained
syn keyword texTex overwithdelims pagedepth pagefilllstretch pagefillstretch pagefilstretch contained
syn keyword texTex pagegoal pageshrink pagestretch pagetotal par contained
syn keyword texTex parfillleftskip parfillskip parindent parinitleftskip parinitrightskip contained
syn keyword texTex parshape parskip patterns pausing penalty contained
syn keyword texTex postdisplaypenalty predisplaypenalty predisplaysize pretolerance prevdepth contained
syn keyword texTex prevgraf radical raise relax relpenalty contained
syn keyword texTex right righthyphenmin rightskip romannumeral scaledfontdimen contained
syn keyword texTex scriptfont scriptscriptfont scriptscriptstyle scriptspace scriptstyle contained
syn keyword texTex scrollmode setbox setlanguage sfcode shipout contained
syn keyword texTex show showbox showboxbreadth showboxdepth showlists contained
syn keyword texTex shownodedetails showthe skewchar skip skipdef contained
syn keyword texTex spacefactor spaceskip span splitbotmark splitfirstmark contained
syn keyword texTex splitmaxdepth splittopskip srule string tabskip contained
syn keyword texTex textfont textstyle the thickmuskip thinmuskip contained
syn keyword texTex time toks toksdef tolerance topmark contained
syn keyword texTex topskip tracingcommands tracinglostchars tracingmacros tracingonline contained
syn keyword texTex tracingoutput tracingpages tracingparagraphs tracingrestores tracingstats contained
syn keyword texTex uccode uchyph unboundary underline unhbox contained
syn keyword texTex unhcopy unhpack unkern unpenalty unskip contained
syn keyword texTex unvbox unvcopy unvpack uppercase vadjust contained
syn keyword texTex valign vbadness vbox vcenter vfil contained
syn keyword texTex vfill vfilneg vfuzz vrule vsize contained
syn keyword texTex vskip vsplit vss vtop wd contained
syn keyword texTex widowpenalty xdef xleaders xspaceskip year contained
syn keyword texXetex XeTeXversion contained
