vim9script

# Vim syntax file
# Language: ConTeXt
# Automatically generated by mtx-interface (2022-08-12 10:49)

syn keyword contextConstants zerocount minusone minustwo plusone plustwo contained
syn keyword contextConstants plusthree plusfour plusfive plussix plusseven contained
syn keyword contextConstants pluseight plusnine plusten pluseleven plustwelve contained
syn keyword contextConstants plussixteen plusfifty plushundred plusonehundred plustwohundred contained
syn keyword contextConstants plusfivehundred plusthousand plustenthousand plustwentythousand medcard contained
syn keyword contextConstants maxcard maxcardminusone zeropoint onepoint halfapoint contained
syn keyword contextConstants onebasepoint maxcount maxdimen scaledpoint thousandpoint contained
syn keyword contextConstants points halfpoint zeroskip centeringskip stretchingskip contained
syn keyword contextConstants shrinkingskip centeringfillskip stretchingfillskip shrinkingfillskip zeromuskip contained
syn keyword contextConstants onemuskip pluscxxvii pluscxxviii pluscclv pluscclvi contained
syn keyword contextConstants normalpagebox binaryshiftedten binaryshiftedtwenty binaryshiftedthirty thickermuskip contained
syn keyword contextConstants directionlefttoright directionrighttoleft endoflinetoken outputnewlinechar emptytoks contained
syn keyword contextConstants empty undefined prerollrun voidbox emptybox contained
syn keyword contextConstants emptyvbox emptyhbox bigskipamount medskipamount smallskipamount contained
syn keyword contextConstants fmtname fmtversion texengine texenginename texengineversion contained
syn keyword contextConstants texenginefunctionality luatexengine pdftexengine xetexengine unknownengine contained
syn keyword contextConstants contextformat contextversion contextlmtxmode contextmark mksuffix contained
syn keyword contextConstants activecatcode bgroup egroup endline conditionaltrue contained
syn keyword contextConstants conditionalfalse attributeunsetvalue statuswrite uprotationangle rightrotationangle contained
syn keyword contextConstants downrotationangle leftrotationangle inicatcodes ctxcatcodes texcatcodes contained
syn keyword contextConstants notcatcodes txtcatcodes vrbcatcodes prtcatcodes nilcatcodes contained
syn keyword contextConstants luacatcodes tpacatcodes tpbcatcodes xmlcatcodes ctdcatcodes contained
syn keyword contextConstants rlncatcodes escapecatcode begingroupcatcode endgroupcatcode mathshiftcatcode contained
syn keyword contextConstants alignmentcatcode endoflinecatcode parametercatcode superscriptcatcode subscriptcatcode contained
syn keyword contextConstants ignorecatcode spacecatcode lettercatcode othercatcode activecatcode contained
syn keyword contextConstants commentcatcode invalidcatcode tabasciicode newlineasciicode formfeedasciicode contained
syn keyword contextConstants endoflineasciicode endoffileasciicode commaasciicode spaceasciicode periodasciicode contained
syn keyword contextConstants hashasciicode dollarasciicode commentasciicode ampersandasciicode colonasciicode contained
syn keyword contextConstants backslashasciicode circumflexasciicode underscoreasciicode leftbraceasciicode barasciicode contained
syn keyword contextConstants rightbraceasciicode tildeasciicode delasciicode leftparentasciicode rightparentasciicode contained
syn keyword contextConstants lessthanasciicode morethanasciicode doublecommentsignal atsignasciicode exclamationmarkasciicode contained
syn keyword contextConstants questionmarkasciicode doublequoteasciicode singlequoteasciicode forwardslashasciicode primeasciicode contained
syn keyword contextConstants hyphenasciicode percentasciicode leftbracketasciicode rightbracketasciicode hsizefrozenparcode contained
syn keyword contextConstants skipfrozenparcode hangfrozenparcode indentfrozenparcode parfillfrozenparcode adjustfrozenparcode contained
syn keyword contextConstants protrudefrozenparcode tolerancefrozenparcode stretchfrozenparcode loosenessfrozenparcode lastlinefrozenparcode contained
syn keyword contextConstants linepenaltyfrozenparcode clubpenaltyfrozenparcode widowpenaltyfrozenparcode displaypenaltyfrozenparcode brokenpenaltyfrozenparcode contained
syn keyword contextConstants demeritsfrozenparcode shapefrozenparcode linefrozenparcode hyphenationfrozenparcode shapingpenaltyfrozenparcode contained
syn keyword contextConstants orphanpenaltyfrozenparcode allfrozenparcode mathpenaltyfrozenparcode activemathcharcode activetabtoken contained
syn keyword contextConstants activeformfeedtoken activeendoflinetoken batchmodecode nonstopmodecode scrollmodecode contained
syn keyword contextConstants errorstopmodecode bottomlevelgroupcode simplegroupcode hboxgroupcode adjustedhboxgroupcode contained
syn keyword contextConstants vboxgroupcode vtopgroupcode aligngroupcode noaligngroupcode outputgroupcode contained
syn keyword contextConstants mathgroupcode discretionarygroupcode insertgroupcode vadjustgroupcode vcentergroupcode contained
syn keyword contextConstants mathabovegroupcode mathchoicegroupcode alsosimplegroupcode semisimplegroupcode mathshiftgroupcode contained
syn keyword contextConstants mathleftgroupcode localboxgroupcode splitoffgroupcode splitkeepgroupcode preamblegroupcode contained
syn keyword contextConstants alignsetgroupcode finrowgroupcode discretionarygroupcode markautomigrationcode insertautomigrationcode contained
syn keyword contextConstants adjustautomigrationcode preautomigrationcode postautomigrationcode charnodecode hlistnodecode contained
syn keyword contextConstants vlistnodecode rulenodecode insertnodecode marknodecode adjustnodecode contained
syn keyword contextConstants ligaturenodecode discretionarynodecode whatsitnodecode mathnodecode gluenodecode contained
syn keyword contextConstants kernnodecode penaltynodecode unsetnodecode mathsnodecode charifcode contained
syn keyword contextConstants catifcode numifcode dimifcode oddifcode vmodeifcode contained
syn keyword contextConstants hmodeifcode mmodeifcode innerifcode voidifcode hboxifcode contained
syn keyword contextConstants vboxifcode xifcode eofifcode trueifcode falseifcode contained
syn keyword contextConstants caseifcode definedifcode csnameifcode fontcharifcode overrulemathcontrolcode contained
syn keyword contextConstants underrulemathcontrolcode radicalrulemathcontrolcode fractionrulemathcontrolcode accentskewhalfmathcontrolcode accentskewapplymathcontrolcode contained
syn keyword contextConstants applyordinarykernpairmathcontrolcode applyverticalitalickernmathcontrolcode applyordinaryitalickernmathcontrolcode applycharitalickernmathcontrolcode reboxcharitalickernmathcontrolcode contained
syn keyword contextConstants applyboxeditalickernmathcontrolcode staircasekernmathcontrolcode applytextitalickernmathcontrolcode applyscriptitalickernmathcontrolcode checkspaceitalickernmathcontrolcode contained
syn keyword contextConstants checktextitalickernmathcontrolcode analyzescriptnucleuscharmathcontrolcode analyzescriptnucleuslistmathcontrolcode analyzescriptnucleusboxmathcontrolcode noligaturingglyphoptioncode contained
syn keyword contextConstants nokerningglyphoptioncode noexpansionglyphoptioncode noprotrusionglyphoptioncode noleftkerningglyphoptioncode noleftligaturingglyphoptioncode contained
syn keyword contextConstants norightkerningglyphoptioncode norightligaturingglyphoptioncode noitaliccorrectionglyphoptioncode normalparcontextcode vmodeparcontextcode contained
syn keyword contextConstants vboxparcontextcode vtopparcontextcode vcenterparcontextcode vadjustparcontextcode insertparcontextcode contained
syn keyword contextConstants outputparcontextcode alignparcontextcode noalignparcontextcode spanparcontextcode resetparcontextcode contained
syn keyword contextConstants leftoriginlistanchorcode leftheightlistanchorcode leftdepthlistanchorcode rightoriginlistanchorcode rightheightlistanchorcode contained
syn keyword contextConstants rightdepthlistanchorcode centeroriginlistanchorcode centerheightlistanchorcode centerdepthlistanchorcode halfwaytotallistanchorcode contained
syn keyword contextConstants halfwayheightlistanchorcode halfwaydepthlistanchorcode halfwayleftlistanchorcode halfwayrightlistanchorcode negatexlistsigncode contained
syn keyword contextConstants negateylistsigncode negatelistsigncode fontslantperpoint fontinterwordspace fontinterwordstretch contained
syn keyword contextConstants fontinterwordshrink fontexheight fontemwidth fontextraspace slantperpoint contained
syn keyword contextConstants mathexheight mathemwidth interwordspace interwordstretch interwordshrink contained
syn keyword contextConstants exheight emwidth extraspace mathaxisheight muquad contained
syn keyword contextConstants startmode stopmode startnotmode stopnotmode startmodeset contained
syn keyword contextConstants stopmodeset doifmode doifelsemode doifmodeelse doifnotmode contained
syn keyword contextConstants startmodeset stopmodeset startallmodes stopallmodes startnotallmodes contained
syn keyword contextConstants stopnotallmodes doifallmodes doifelseallmodes doifallmodeselse doifnotallmodes contained
syn keyword contextConstants startenvironment stopenvironment environment startcomponent stopcomponent contained
syn keyword contextConstants component startproduct stopproduct product startproject contained
syn keyword contextConstants stopproject project starttext stoptext startnotext contained
syn keyword contextConstants stopnotext startdocument stopdocument documentvariable unexpandeddocumentvariable contained
syn keyword contextConstants setupdocument presetdocument doifelsedocumentvariable doifdocumentvariableelse doifdocumentvariable contained
syn keyword contextConstants doifnotdocumentvariable startmodule stopmodule usemodule usetexmodule contained
syn keyword contextConstants useluamodule setupmodule currentmoduleparameter moduleparameter everystarttext contained
syn keyword contextConstants everystoptext startTEXpage stopTEXpage enablemode disablemode contained
syn keyword contextConstants preventmode definemode globalenablemode globaldisablemode globalpreventmode contained
syn keyword contextConstants pushmode popmode typescriptone typescripttwo typescriptthree contained
syn keyword contextConstants mathsizesuffix mathordinarycode mathordcode mathoperatorcode mathopcode contained
syn keyword contextConstants mathbinarycode mathbincode mathrelationcode mathrelcode mathopencode contained
syn keyword contextConstants mathclosecode mathpunctuationcode mathpunctcode mathovercode mathundercode contained
syn keyword contextConstants mathinnercode mathradicalcode mathfractioncode mathmiddlecode mathaccentcode contained
syn keyword contextConstants mathfencedcode mathghostcode mathvariablecode mathactivecode mathvcentercode contained
syn keyword contextConstants mathconstructcode mathwrappedcode mathbegincode mathendcode mathexplicitcode contained
syn keyword contextConstants mathdivisioncode mathfactorialcode mathdimensioncode mathexperimentalcode mathtextpunctuationcode contained
syn keyword contextConstants mathimaginarycode mathdifferentialcode mathexponentialcode mathellipsiscode mathfunctioncode contained
syn keyword contextConstants mathdigitcode mathalphacode mathboxcode mathchoicecode mathnothingcode contained
syn keyword contextConstants mathlimopcode mathnolopcode mathunsetcode mathunspacedcode mathallcode contained
syn keyword contextConstants mathfakecode mathunarycode constantnumber constantnumberargument constantdimen contained
syn keyword contextConstants constantdimenargument constantemptyargument luastringsep !!bs !!es contained
syn keyword contextConstants lefttorightmark righttoleftmark lrm rlm bidilre contained
syn keyword contextConstants bidirle bidipop bidilro bidirlo breakablethinspace contained
syn keyword contextConstants nobreakspace nonbreakablespace narrownobreakspace zerowidthnobreakspace ideographicspace contained
syn keyword contextConstants ideographichalffillspace twoperemspace threeperemspace fourperemspace fiveperemspace contained
syn keyword contextConstants sixperemspace figurespace punctuationspace hairspace enquad contained
syn keyword contextConstants emquad zerowidthspace zerowidthnonjoiner zerowidthjoiner zwnj contained
syn keyword contextConstants zwj optionalspace asciispacechar softhyphen Ux contained
syn keyword contextConstants eUx Umathaccents parfillleftskip parfillrightskip startlmtxmode contained
syn keyword contextConstants stoplmtxmode startmkivmode stopmkivmode wildcardsymbol normalhyphenationcode contained
syn keyword contextConstants automatichyphenationcode explicithyphenationcode syllablehyphenationcode uppercasehyphenationcode collapsehyphenationcode contained
syn keyword contextConstants compoundhyphenationcode strictstarthyphenationcode strictendhyphenationcode automaticpenaltyhyphenationcode explicitpenaltyhyphenationcode contained
syn keyword contextConstants permitgluehyphenationcode permitallhyphenationcode permitmathreplacehyphenationcode forcecheckhyphenationcode lazyligatureshyphenationcode contained
syn keyword contextConstants forcehandlerhyphenationcode feedbackcompoundhyphenationcode ignoreboundshyphenationcode partialhyphenationcode completehyphenationcode contained
syn keyword contextConstants normalizelinenormalizecode parindentskipnormalizecode swaphangindentnormalizecode swapparsshapenormalizecode breakafterdirnormalizecode contained
syn keyword contextConstants removemarginkernsnormalizecode clipwidthnormalizecode flattendiscretionariesnormalizecode discardzerotabskipsnormalizecode flattenhleadersnormalizecode contained
syn keyword contextConstants normalizeparnormalizeparcode flattenvleadersnormalizeparcode nopreslackclassoptioncode nopostslackclassoptioncode lefttopkernclassoptioncode contained
syn keyword contextConstants righttopkernclassoptioncode leftbottomkernclassoptioncode rightbottomkernclassoptioncode lookaheadforendclassoptioncode noitaliccorrectionclassoptioncode contained
syn keyword contextConstants defaultmathclassoptions checkligatureclassoptioncode checkitaliccorrectionclassoptioncode checkkernpairclassoptioncode flattenclassoptioncode contained
syn keyword contextConstants omitpenaltyclassoptioncode unpackclassoptioncode raiseprimeclassoptioncode carryoverlefttopkernclassoptioncode carryoverleftbottomkernclassoptioncode contained
syn keyword contextConstants carryoverrighttopkernclassoptioncode carryoverrightbottomkernclassoptioncode preferdelimiterdimensionsclassoptioncode noligaturingglyphoptioncode nokerningglyphoptioncode contained
syn keyword contextConstants noleftligatureglyphoptioncode noleftkernglyphoptioncode norightligatureglyphoptioncode norightkernglyphoptioncode noexpansionglyphoptioncode contained
syn keyword contextConstants noprotrusionglyphoptioncode noitaliccorrectionglyphoptioncode nokerningcode noligaturingcode frozenflagcode contained
syn keyword contextConstants tolerantflagcode protectedflagcode primitiveflagcode permanentflagcode noalignedflagcode contained
syn keyword contextConstants immutableflagcode mutableflagcode globalflagcode overloadedflagcode immediateflagcode contained
syn keyword contextConstants conditionalflagcode valueflagcode instanceflagcode ordmathflattencode binmathflattencode contained
syn keyword contextConstants relmathflattencode punctmathflattencode innermathflattencode normalworddiscoptioncode preworddiscoptioncode contained
syn keyword contextConstants postworddiscoptioncode continueifinputfile continuewhenlmtxmode continuewhenmkivmode contained
syn keyword contextHelpers startsetups stopsetups startxmlsetups stopxmlsetups startluasetups contained
syn keyword contextHelpers stopluasetups starttexsetups stoptexsetups startrawsetups stoprawsetups contained
syn keyword contextHelpers startlocalsetups stoplocalsetups starttexdefinition stoptexdefinition starttexcode contained
syn keyword contextHelpers stoptexcode startcontextcode stopcontextcode startcontextdefinitioncode stopcontextdefinitioncode contained
syn keyword contextHelpers texdefinition doifelsesetups doifsetupselse doifsetups doifnotsetups contained
syn keyword contextHelpers setup setups texsetup xmlsetup luasetup contained
syn keyword contextHelpers directsetup fastsetup copysetups resetsetups doifelsecommandhandler contained
syn keyword contextHelpers doifcommandhandlerelse doifnotcommandhandler doifcommandhandler newmode setmode contained
syn keyword contextHelpers resetmode newsystemmode setsystemmode resetsystemmode pushsystemmode contained
syn keyword contextHelpers popsystemmode globalsetmode globalresetmode globalsetsystemmode globalresetsystemmode contained
syn keyword contextHelpers booleanmodevalue newcount newdimen newskip newmuskip contained
syn keyword contextHelpers newbox newtoks newread newwrite newmarks contained
syn keyword contextHelpers newinsert newattribute newif newlanguage newfamily contained
syn keyword contextHelpers newfam newhelp then begcsname autorule contained
syn keyword contextHelpers strippedcsname checkedstrippedcsname nofarguments firstargumentfalse firstargumenttrue contained
syn keyword contextHelpers secondargumentfalse secondargumenttrue thirdargumentfalse thirdargumenttrue fourthargumentfalse contained
syn keyword contextHelpers fourthargumenttrue fifthargumentfalse fifthargumenttrue sixthargumentfalse sixthargumenttrue contained
syn keyword contextHelpers seventhargumentfalse seventhargumenttrue vkern hkern vpenalty contained
syn keyword contextHelpers hpenalty doglobal dodoglobal redoglobal resetglobal contained
syn keyword contextHelpers donothing untraceddonothing dontcomplain moreboxtracing lessboxtracing contained
syn keyword contextHelpers noboxtracing forgetall donetrue donefalse foundtrue contained
syn keyword contextHelpers foundfalse inlineordisplaymath indisplaymath forcedisplaymath startforceddisplaymath contained
syn keyword contextHelpers stopforceddisplaymath startpickupmath stoppickupmath reqno forceinlinemath contained
syn keyword contextHelpers mathortext thebox htdp unvoidbox hfilll contained
syn keyword contextHelpers vfilll mathbox mathlimop mathnolop mathnothing contained
syn keyword contextHelpers mathalpha currentcatcodetable defaultcatcodetable catcodetablename newcatcodetable contained
syn keyword contextHelpers startcatcodetable stopcatcodetable startextendcatcodetable stopextendcatcodetable pushcatcodetable contained
syn keyword contextHelpers popcatcodetable restorecatcodes setcatcodetable letcatcodecommand defcatcodecommand contained
syn keyword contextHelpers uedcatcodecommand hglue vglue hfillneg vfillneg contained
syn keyword contextHelpers hfilllneg vfilllneg ruledhss ruledhfil ruledhfill contained
syn keyword contextHelpers ruledhfilll ruledhfilneg ruledhfillneg normalhfillneg normalhfilllneg contained
syn keyword contextHelpers ruledvss ruledvfil ruledvfill ruledvfilll ruledvfilneg contained
syn keyword contextHelpers ruledvfillneg normalvfillneg normalvfilllneg ruledhbox ruledvbox contained
syn keyword contextHelpers ruledvtop ruledvcenter ruledmbox ruledhpack ruledvpack contained
syn keyword contextHelpers ruledtpack ruledhskip ruledvskip ruledkern ruledmskip contained
syn keyword contextHelpers ruledmkern ruledhglue ruledvglue normalhglue normalvglue contained
syn keyword contextHelpers ruledpenalty filledhboxb filledhboxr filledhboxg filledhboxc contained
syn keyword contextHelpers filledhboxm filledhboxy filledhboxk scratchstring scratchstringone contained
syn keyword contextHelpers scratchstringtwo tempstring scratchcounter globalscratchcounter privatescratchcounter contained
syn keyword contextHelpers scratchdimen globalscratchdimen privatescratchdimen scratchskip globalscratchskip contained
syn keyword contextHelpers privatescratchskip scratchmuskip globalscratchmuskip privatescratchmuskip scratchtoks contained
syn keyword contextHelpers globalscratchtoks privatescratchtoks scratchbox globalscratchbox privatescratchbox contained
syn keyword contextHelpers scratchmacro scratchmacroone scratchmacrotwo scratchconditiontrue scratchconditionfalse contained
syn keyword contextHelpers ifscratchcondition scratchconditiononetrue scratchconditiononefalse ifscratchconditionone scratchconditiontwotrue contained
syn keyword contextHelpers scratchconditiontwofalse ifscratchconditiontwo globalscratchcounterone globalscratchcountertwo globalscratchcounterthree contained
syn keyword contextHelpers groupedcommand groupedcommandcs triggergroupedcommand triggergroupedcommandcs simplegroupedcommand contained
syn keyword contextHelpers simplegroupedcommandcs pickupgroupedcommand pickupgroupedcommandcs mathgroupedcommandcs usedbaselineskip contained
syn keyword contextHelpers usedlineskip usedlineskiplimit availablehsize localhsize setlocalhsize contained
syn keyword contextHelpers distributedhsize hsizefraction next nexttoken nextbox contained
syn keyword contextHelpers dowithnextbox dowithnextboxcs dowithnextboxcontent dowithnextboxcontentcs flushnextbox contained
syn keyword contextHelpers boxisempty boxtostring contentostring prerolltostring givenwidth contained
syn keyword contextHelpers givenheight givendepth scangivendimensions scratchwidth scratchheight contained
syn keyword contextHelpers scratchdepth scratchoffset scratchdistance scratchtotal scratchitalic contained
syn keyword contextHelpers scratchhsize scratchvsize scratchxoffset scratchyoffset scratchhoffset contained
syn keyword contextHelpers scratchvoffset scratchxposition scratchyposition scratchtopoffset scratchbottomoffset contained
syn keyword contextHelpers scratchleftoffset scratchrightoffset scratchcounterone scratchcountertwo scratchcounterthree contained
syn keyword contextHelpers scratchcounterfour scratchcounterfive scratchcountersix scratchdimenone scratchdimentwo contained
syn keyword contextHelpers scratchdimenthree scratchdimenfour scratchdimenfive scratchdimensix scratchskipone contained
syn keyword contextHelpers scratchskiptwo scratchskipthree scratchskipfour scratchskipfive scratchskipsix contained
syn keyword contextHelpers scratchmuskipone scratchmuskiptwo scratchmuskipthree scratchmuskipfour scratchmuskipfive contained
syn keyword contextHelpers scratchmuskipsix scratchtoksone scratchtokstwo scratchtoksthree scratchtoksfour contained
syn keyword contextHelpers scratchtoksfive scratchtokssix scratchboxone scratchboxtwo scratchboxthree contained
syn keyword contextHelpers scratchboxfour scratchboxfive scratchboxsix scratchnx scratchny contained
syn keyword contextHelpers scratchmx scratchmy scratchunicode scratchmin scratchmax contained
syn keyword contextHelpers scratchleftskip scratchrightskip scratchtopskip scratchbottomskip doif contained
syn keyword contextHelpers doifnot doifelse firstinset doifinset doifnotinset contained
syn keyword contextHelpers doifelseinset doifinsetelse doifelsenextchar doifnextcharelse doifelsenextcharcs contained
syn keyword contextHelpers doifnextcharcselse doifelsenextoptional doifnextoptionalelse doifelsenextoptionalcs doifnextoptionalcselse contained
syn keyword contextHelpers doifelsefastoptionalcheck doiffastoptionalcheckelse doifelsefastoptionalcheckcs doiffastoptionalcheckcselse doifelsenextbgroup contained
syn keyword contextHelpers doifnextbgroupelse doifelsenextbgroupcs doifnextbgroupcselse doifelsenextparenthesis doifnextparenthesiselse contained
syn keyword contextHelpers doifelseundefined doifundefinedelse doifelsedefined doifdefinedelse doifundefined contained
syn keyword contextHelpers doifdefined doifelsevalue doifvalue doifnotvalue doifnothing contained
syn keyword contextHelpers doifsomething doifelsenothing doifnothingelse doifelsesomething doifsomethingelse contained
syn keyword contextHelpers doifvaluenothing doifvaluesomething doifelsevaluenothing doifvaluenothingelse doifelsedimension contained
syn keyword contextHelpers doifdimensionelse doifelsenumber doifnumberelse doifnumber doifnotnumber contained
syn keyword contextHelpers doifelsecommon doifcommonelse doifcommon doifnotcommon doifinstring contained
syn keyword contextHelpers doifnotinstring doifelseinstring doifinstringelse doifelseassignment doifassignmentelse contained
syn keyword contextHelpers docheckassignment doifelseassignmentcs doifassignmentelsecs validassignment novalidassignment contained
syn keyword contextHelpers doiftext doifelsetext doiftextelse doifnottext quitcondition contained
syn keyword contextHelpers truecondition falsecondition tracingall tracingnone loggingall contained
syn keyword contextHelpers tracingcatcodes showluatokens aliasmacro removetoks appendtoks contained
syn keyword contextHelpers prependtoks appendtotoks prependtotoks to endgraf contained
syn keyword contextHelpers endpar reseteverypar finishpar empty null contained
syn keyword contextHelpers space quad enspace emspace charspace contained
syn keyword contextHelpers nbsp crlf obeyspaces obeylines obeytabs contained
syn keyword contextHelpers obeypages obeyedspace obeyedline obeyedtab obeyedpage contained
syn keyword contextHelpers normalspace naturalspace controlspace normalspaces ignoretabs contained
syn keyword contextHelpers ignorelines ignorepages ignoreeofs setcontrolspaces executeifdefined contained
syn keyword contextHelpers singleexpandafter doubleexpandafter tripleexpandafter dontleavehmode removelastspace contained
syn keyword contextHelpers removeunwantedspaces keepunwantedspaces removepunctuation ignoreparskip forcestrutdepth contained
syn keyword contextHelpers onlynonbreakablespace wait writestatus define defineexpandable contained
syn keyword contextHelpers redefine setmeasure setemeasure setgmeasure setxmeasure contained
syn keyword contextHelpers definemeasure freezemeasure measure measured directmeasure contained
syn keyword contextHelpers setquantity setequantity setgquantity setxquantity definequantity contained
syn keyword contextHelpers freezequantity quantity quantitied directquantity installcorenamespace contained
syn keyword contextHelpers getvalue getuvalue setvalue setevalue setgvalue contained
syn keyword contextHelpers setxvalue letvalue letgvalue resetvalue undefinevalue contained
syn keyword contextHelpers ignorevalue setuvalue setuevalue setugvalue setuxvalue contained
syn keyword contextHelpers globallet udef ugdef uedef uxdef contained
syn keyword contextHelpers checked unique getparameters geteparameters getgparameters contained
syn keyword contextHelpers getxparameters forgetparameters copyparameters getdummyparameters dummyparameter contained
syn keyword contextHelpers directdummyparameter setdummyparameter letdummyparameter setexpandeddummyparameter usedummystyleandcolor contained
syn keyword contextHelpers usedummystyleparameter usedummycolorparameter processcommalist processcommacommand quitcommalist contained
syn keyword contextHelpers quitprevcommalist processaction processallactions processfirstactioninset processallactionsinset contained
syn keyword contextHelpers unexpanded expanded startexpanded stopexpanded protect contained
syn keyword contextHelpers unprotect firstofoneargument firstoftwoarguments secondoftwoarguments firstofthreearguments contained
syn keyword contextHelpers secondofthreearguments thirdofthreearguments firstoffourarguments secondoffourarguments thirdoffourarguments contained
syn keyword contextHelpers fourthoffourarguments firstoffivearguments secondoffivearguments thirdoffivearguments fourthoffivearguments contained
syn keyword contextHelpers fifthoffivearguments firstofsixarguments secondofsixarguments thirdofsixarguments fourthofsixarguments contained
syn keyword contextHelpers fifthofsixarguments sixthofsixarguments firstofoneunexpanded firstoftwounexpanded secondoftwounexpanded contained
syn keyword contextHelpers firstofthreeunexpanded secondofthreeunexpanded thirdofthreeunexpanded gobbleoneargument gobbletwoarguments contained
syn keyword contextHelpers gobblethreearguments gobblefourarguments gobblefivearguments gobblesixarguments gobblesevenarguments contained
syn keyword contextHelpers gobbleeightarguments gobbleninearguments gobbletenarguments gobbleoneoptional gobbletwooptionals contained
syn keyword contextHelpers gobblethreeoptionals gobblefouroptionals gobblefiveoptionals dorecurse doloop contained
syn keyword contextHelpers exitloop dostepwiserecurse recurselevel recursedepth dofastloopcs contained
syn keyword contextHelpers fastloopindex fastloopfinal dowith doloopovermatch doloopovermatched contained
syn keyword contextHelpers doloopoverlist newconstant setnewconstant setconstant setconstantvalue contained
syn keyword contextHelpers newconditional settrue setfalse settruevalue setfalsevalue contained
syn keyword contextHelpers setconditional newmacro setnewmacro newfraction newsignal contained
syn keyword contextHelpers newboundary dosingleempty dodoubleempty dotripleempty doquadrupleempty contained
syn keyword contextHelpers doquintupleempty dosixtupleempty doseventupleempty dosingleargument dodoubleargument contained
syn keyword contextHelpers dotripleargument doquadrupleargument doquintupleargument dosixtupleargument doseventupleargument contained
syn keyword contextHelpers dosinglegroupempty dodoublegroupempty dotriplegroupempty doquadruplegroupempty doquintuplegroupempty contained
syn keyword contextHelpers permitspacesbetweengroups dontpermitspacesbetweengroups nopdfcompression maximumpdfcompression normalpdfcompression contained
syn keyword contextHelpers onlypdfobjectcompression nopdfobjectcompression modulonumber dividenumber getfirstcharacter contained
syn keyword contextHelpers doifelsefirstchar doiffirstcharelse mathclassvalue startnointerference stopnointerference contained
syn keyword contextHelpers twodigits threedigits leftorright offinterlineskip oninterlineskip contained
syn keyword contextHelpers nointerlineskip strut halfstrut quarterstrut depthstrut contained
syn keyword contextHelpers halflinestrut noheightstrut setstrut strutbox strutht contained
syn keyword contextHelpers strutdp strutwd struthtdp strutgap begstrut contained
syn keyword contextHelpers endstrut lineheight leftboundary rightboundary signalcharacter contained
syn keyword contextHelpers aligncontentleft aligncontentmiddle aligncontentright shiftbox vpackbox contained
syn keyword contextHelpers hpackbox vpackedbox hpackedbox ordordspacing ordopspacing contained
syn keyword contextHelpers ordbinspacing ordrelspacing ordopenspacing ordclosespacing ordpunctspacing contained
syn keyword contextHelpers ordinnerspacing ordfracspacing ordradspacing ordmiddlespacing ordaccentspacing contained
syn keyword contextHelpers opordspacing opopspacing opbinspacing oprelspacing opopenspacing contained
syn keyword contextHelpers opclosespacing oppunctspacing opinnerspacing opfracspacing opradspacing contained
syn keyword contextHelpers opmiddlespacing opaccentspacing binordspacing binopspacing binbinspacing contained
syn keyword contextHelpers binrelspacing binopenspacing binclosespacing binpunctspacing bininnerspacing contained
syn keyword contextHelpers binfracspacing binradspacing binmiddlespacing binaccentspacing relordspacing contained
syn keyword contextHelpers relopspacing relbinspacing relrelspacing relopenspacing relclosespacing contained
syn keyword contextHelpers relpunctspacing relinnerspacing relfracspacing relradspacing relmiddlespacing contained
syn keyword contextHelpers relaccentspacing openordspacing openopspacing openbinspacing openrelspacing contained
syn keyword contextHelpers openopenspacing openclosespacing openpunctspacing openinnerspacing openfracspacing contained
syn keyword contextHelpers openradspacing openmiddlespacing openaccentspacing closeordspacing closeopspacing contained
syn keyword contextHelpers closebinspacing closerelspacing closeopenspacing closeclosespacing closepunctspacing contained
syn keyword contextHelpers closeinnerspacing closefracspacing closeradspacing closemiddlespacing closeaccentspacing contained
syn keyword contextHelpers punctordspacing punctopspacing punctbinspacing punctrelspacing punctopenspacing contained
syn keyword contextHelpers punctclosespacing punctpunctspacing punctinnerspacing punctfracspacing punctradspacing contained
syn keyword contextHelpers punctmiddlespacing punctaccentspacing innerordspacing inneropspacing innerbinspacing contained
syn keyword contextHelpers innerrelspacing inneropenspacing innerclosespacing innerpunctspacing innerinnerspacing contained
syn keyword contextHelpers innerfracspacing innerradspacing innermiddlespacing inneraccentspacing fracordspacing contained
syn keyword contextHelpers fracopspacing fracbinspacing fracrelspacing fracopenspacing fracclosespacing contained
syn keyword contextHelpers fracpunctspacing fracinnerspacing fracfracspacing fracradspacing fracmiddlespacing contained
syn keyword contextHelpers fracaccentspacing radordspacing radopspacing radbinspacing radrelspacing contained
syn keyword contextHelpers radopenspacing radclosespacing radpunctspacing radinnerspacing radfracspacing contained
syn keyword contextHelpers radradspacing radmiddlespacing radaccentspacing middleordspacing middleopspacing contained
syn keyword contextHelpers middlebinspacing middlerelspacing middleopenspacing middleclosespacing middlepunctspacing contained
syn keyword contextHelpers middleinnerspacing middlefracspacing middleradspacing middlemiddlespacing middleaccentspacing contained
syn keyword contextHelpers accentordspacing accentopspacing accentbinspacing accentrelspacing accentopenspacing contained
syn keyword contextHelpers accentclosespacing accentpunctspacing accentinnerspacing accentfracspacing accentradspacing contained
syn keyword contextHelpers accentmiddlespacing accentaccentspacing normalreqno startimath stopimath contained
syn keyword contextHelpers normalstartimath normalstopimath startdmath stopdmath normalstartdmath contained
syn keyword contextHelpers normalstopdmath normalsuperscript normalsubscript normalnosuperscript normalnosubscript contained
syn keyword contextHelpers normalprimescript superscript subscript nosuperscript nosubscript contained
syn keyword contextHelpers primescript superprescript subprescript nosuperprescript nosubsprecript contained
syn keyword contextHelpers uncramped cramped mathstyletrigger triggermathstyle triggeredmathstyle contained
syn keyword contextHelpers mathstylefont mathsmallstylefont mathstyleface mathsmallstyleface mathstylecommand contained
syn keyword contextHelpers mathpalette mathstylehbox mathstylevbox mathstylevcenter mathstylevcenteredhbox contained
syn keyword contextHelpers mathstylevcenteredvbox mathtext setmathsmalltextbox setmathtextbox pushmathstyle contained
syn keyword contextHelpers popmathstyle triggerdisplaystyle triggertextstyle triggerscriptstyle triggerscriptscriptstyle contained
syn keyword contextHelpers triggeruncrampedstyle triggercrampedstyle triggersmallstyle triggeruncrampedsmallstyle triggercrampedsmallstyle contained
syn keyword contextHelpers triggerbigstyle triggeruncrampedbigstyle triggercrampedbigstyle luaexpr expelsedoif contained
syn keyword contextHelpers expdoif expdoifnot expdoifelsecommon expdoifcommonelse expdoifelseinset contained
syn keyword contextHelpers expdoifinsetelse ctxdirectlua ctxlatelua ctxsprint ctxwrite contained
syn keyword contextHelpers ctxcommand ctxdirectcommand ctxlatecommand ctxreport ctxlua contained
syn keyword contextHelpers luacode lateluacode directluacode registerctxluafile ctxloadluafile contained
syn keyword contextHelpers luaversion luamajorversion luaminorversion ctxluacode luaconditional contained
syn keyword contextHelpers luaexpanded ctxluamatch startluaparameterset stopluaparameterset luaparameterset contained
syn keyword contextHelpers definenamedlua obeylualines obeyluatokens startluacode stopluacode contained
syn keyword contextHelpers startlua stoplua startctxfunction stopctxfunction ctxfunction contained
syn keyword contextHelpers startctxfunctiondefinition stopctxfunctiondefinition installctxfunction installprotectedctxfunction installprotectedctxscanner contained
syn keyword contextHelpers installctxscanner resetctxscanner cldprocessfile cldloadfile cldloadviafile contained
syn keyword contextHelpers cldcontext cldcommand carryoverpar freezeparagraphproperties defrostparagraphproperties contained
syn keyword contextHelpers setparagraphfreezing forgetparagraphfreezing updateparagraphproperties updateparagraphpenalties updateparagraphdemerits contained
syn keyword contextHelpers updateparagraphshapes updateparagraphlines lastlinewidth assumelongusagecs Umathbotaccent contained
syn keyword contextHelpers Umathtopaccent righttolefthbox lefttorighthbox righttoleftvbox lefttorightvbox contained
syn keyword contextHelpers righttoleftvtop lefttorightvtop rtlhbox ltrhbox rtlvbox contained
syn keyword contextHelpers ltrvbox rtlvtop ltrvtop autodirhbox autodirvbox contained
syn keyword contextHelpers autodirvtop leftorrighthbox leftorrightvbox leftorrightvtop lefttoright contained
syn keyword contextHelpers righttoleft checkedlefttoright checkedrighttoleft synchronizelayoutdirection synchronizedisplaydirection contained
syn keyword contextHelpers synchronizeinlinedirection dirlre dirrle dirlro dirrlo contained
syn keyword contextHelpers rtltext ltrtext lesshyphens morehyphens nohyphens contained
syn keyword contextHelpers dohyphens dohyphencollapsing nohyphencollapsing compounddiscretionary Ucheckedstartdisplaymath contained
syn keyword contextHelpers Ucheckedstopdisplaymath break nobreak allowbreak goodbreak contained
syn keyword contextHelpers nospace nospacing dospacing naturalhbox naturalvbox contained
syn keyword contextHelpers naturalvtop naturalhpack naturalvpack naturaltpack reversehbox contained
syn keyword contextHelpers reversevbox reversevtop reversehpack reversevpack reversetpack contained
syn keyword contextHelpers hcontainer vcontainer tcontainer frule compoundhyphenpenalty contained
syn keyword contextHelpers start stop unsupportedcs openout closeout contained
syn keyword contextHelpers write openin closein read readline contained
syn keyword contextHelpers readfromterminal boxlines boxline setboxline copyboxline contained
syn keyword contextHelpers boxlinewd boxlineht boxlinedp boxlinenw boxlinenh contained
syn keyword contextHelpers boxlinend boxlinels boxliners boxlinelh boxlinerh contained
syn keyword contextHelpers boxlinelp boxlinerp boxlinein boxrangewd boxrangeht contained
syn keyword contextHelpers boxrangedp bitwiseset bitwiseand bitwiseor bitwisexor contained
syn keyword contextHelpers bitwisenot bitwisenil ifbitwiseand bitwise bitwiseshift contained
syn keyword contextHelpers bitwiseflip textdir linedir pardir boxdir contained
syn keyword contextHelpers prelistbox postlistbox prelistcopy postlistcopy setprelistbox contained
syn keyword contextHelpers setpostlistbox noligaturing nokerning noexpansion noprotrusion contained
syn keyword contextHelpers noleftkerning noleftligaturing norightkerning norightligaturing noitaliccorrection contained
syn keyword contextHelpers futureletnexttoken defbackslashbreak letbackslashbreak pushoverloadmode popoverloadmode contained
syn keyword contextHelpers pushrunstate poprunstate suggestedalias showboxhere discoptioncodestring contained
syn keyword contextHelpers flagcodestring frozenparcodestring glyphoptioncodestring groupcodestring hyphenationcodestring contained
syn keyword contextHelpers mathcontrolcodestring mathflattencodestring normalizecodestring parcontextcodestring newlocalcount contained
syn keyword contextHelpers newlocaldimen newlocalskip newlocalmuskip newlocaltoks newlocalbox contained
syn keyword contextHelpers newlocalwrite newlocalread setnewlocalcount setnewlocaldimen setnewlocalskip contained
syn keyword contextHelpers setnewlocalmuskip setnewlocaltoks setnewlocalbox ifexpression contained
